California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 92 - COMMUNITY COLLEGES. FUNDING. GOVERNANCE. FEES. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1301493 | CALIFORNIANS FOR FAIR EDUCATION FUNDING, A COALITION OF BUSINESS EDUCATORS AND TAXPAYERS - NO ON 92 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1282453 | YES ON PROPOSITION 92, CAS FOR IMPROVING COMMUNITY COLLEGES, A COALITION OF EDUCATORS AND COMMUNITY COLLEGE ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1302764 | YES ON 92! STUDENTS AND EDUCATORS IN SUPPORT COMMITTEE | SUPPORT